{"": "", "Install/remove packages": "Instal/hapus paket", "Apply changes": "Menerapkan perubahan", "Selections": "Pilihan", "Mark for installation": "Tandai untuk instalasi", "Mark for upgrade": "Tandai untuk upgrade", "Installed": "Dipasang", "Search packages": "Cari paket", "Upgradeable": "Bisa diupgrade", "pending": "tertunda", "Cancel": "Membatalkan", "Close": "Tutup", "Update package list": "Perbarui daftar paket", "Packages": "Paket", "Mark for removal": "Tandai untuk dihapus"}