{"": "", "Install/remove packages": "Instalovat nebo odebrat bal\u00ed\u010dky", "Apply changes": "Pou\u017e\u00edt zm\u011bny", "Selections": "V\u00fdb\u011br", "Mark for installation": "Ozna\u010dit pro instalaci", "Mark for upgrade": "Ozna\u010dit pro upgrade", "Installed": "Nainstalov\u00e1no", "Search packages": "Hled\u00e1n\u00ed bal\u00edk\u016f", "Upgradeable": "Aktualizovateln\u00fd", "pending": "\u010dek\u00e1 na zpracov\u00e1n\u00ed", "Cancel": "Zru\u0161it", "Close": "Zav\u0159\u00edt", "Update package list": "Aktualizovat seznam bal\u00edk\u016f", "Packages": "Bal\u00ed\u010dky", "Mark for removal": "Ozna\u010dit pro odstran\u011bn\u00ed"}