{"": "", "Install/remove packages": "", "Apply changes": "Zastosuj zmiany", "Selections": "", "Mark for installation": "", "Mark for upgrade": "Zaznacz do uaktualnienia", "Installed": "", "Search packages": "", "Upgradeable": "Mo\u017cliwe do zaktualizowania", "pending": "", "Cancel": "Anuluj", "Close": "", "Update package list": "Aktualizacja listy pakiet\u00f3w", "Packages": "Paczki", "Mark for removal": "Zaznacz do usuni\u0119cia"}