{"": "", "Install/remove packages": "Installieren/Entfernen von Paketen", "Apply changes": "\u00c4nderungen \u00fcbernehmen", "Selections": "Auswahl", "Mark for installation": "F\u00fcr Installation markieren", "Mark for upgrade": "F\u00fcr Update markieren", "Installed": "Installiert", "Search packages": "Packete Suchen", "Upgradeable": "Aktualisierbar", "pending": "warten", "Cancel": "Abbrechen", "Close": "Schlie\u00dfen", "Update package list": "Package List aktualisieren", "Packages": "Packete", "Mark for removal": "Zum L\u00f6schen markieren"}