{"": "", "Install/remove packages": "Instalar/remover pacotes", "Apply changes": "Aplicar altera\u00e7\u00f5es", "Selections": "Sele\u00e7\u00f5es", "Mark for installation": "Marcar para instala\u00e7\u00e3o", "Mark for upgrade": "Marcar para atualiza\u00e7\u00e3o", "Installed": "Instalado", "Search packages": "Pesquisar pacotes", "Upgradeable": "Atualiz\u00e1vel", "pending": "pendente", "Cancel": "Cancelar", "Close": "Fechar", "Update package list": "Lista de pacotes de atualiza\u00e7\u00e3o", "Packages": "Pacotes", "Mark for removal": "Marca para remo\u00e7\u00e3o"}