{"": "", "Install/remove packages": "\ud328\ud0a4\uc9c0 \uc124\uce58/\uc0ad\uc81c", "Apply changes": "\ubcc0\uacbd\uc0ac\ud56d \uc801\uc6a9", "Selections": "\uc120\ud0dd", "Mark for installation": "\uc124\uce58\ud560 \ud56d\ubaa9", "Mark for upgrade": "\uc5c5\uadf8\ub808\uc774\ub4dc\ud560 \ud56d\ubaa9", "Installed": "\uc124\uce58\ub428", "Search packages": "\ud328\ud0a4\uc9c0 \uac80\uc0c9", "Upgradeable": "\uc5c5\uadf8\ub808\uc774\ub4dc \uac00\ub2a5", "pending": "", "Cancel": "\ucde8\uc18c", "Close": "\ub2eb\uae30", "Update package list": "\ud328\ud0a4\uc9c0 \ubaa9\ub85d \uc5c5\ub370\uc774\ud2b8", "Packages": "\ud328\ud0a4\uc9c0", "Mark for removal": "\uc0ad\uc81c\ud560 \ud56d\ubaa9"}