{"": "", "Install/remove packages": "Namestite/odstranite pakete", "Apply changes": "Uveljavi spremembe", "Selections": "Izbira", "Mark for installation": "Ozna\u010di za namestitev", "Mark for upgrade": "Ozna\u010di za nadgradnjo", "Installed": "Name\u0161\u010deno", "Search packages": "Iskanje paketov", "Upgradeable": "Nadgradljivo", "pending": "na \u010dakanju", "Cancel": "Prekli\u010di", "Close": "Zapri", "Update package list": "Posodobi seznam paketov", "Packages": "Paketi", "Mark for removal": "Ozna\u010di za odstranitev"}