{"": "", "Install/remove packages": "Paket Y\u00fckle/Kald\u0131r", "Apply changes": "De\u011fi\u015fiklikleri uygula", "Selections": "Se\u00e7imler", "Mark for installation": "Y\u00fckleme i\u00e7in i\u015faretle", "Mark for upgrade": "Y\u00fckseltme i\u00e7in i\u015faretle", "Installed": "Y\u00fckl\u00fc", "Search packages": "Paket ara", "Upgradeable": "Y\u00fckseltilebilir", "pending": "beklemede", "Cancel": "\u0130ptal", "Close": "Kapat", "Update package list": "G\u00fcncelle\u015ftirme paketi listesi", "Packages": "Paketler", "Mark for removal": "Kald\u0131rma i\u00e7in i\u015faretle"}