{"": "", "Install/remove packages": "", "Apply changes": "Pas wijzigingen toe", "Selections": "Selecties", "Mark for installation": "", "Mark for upgrade": "Markeren voor upgrade", "Installed": "Ge\u00efnstalleerd", "Search packages": "", "Upgradeable": "", "pending": "in behandeling", "Cancel": "Annuleren", "Close": "Sluiten", "Update package list": "", "Packages": "", "Mark for removal": "Aanmerken voor verwijdering"}