{"": "", "Install/remove packages": "Installa/Rimuovi pacchetti", "Apply changes": "Applica le modifiche", "Selections": "Selezioni", "Mark for installation": "Seleziona per installazione", "Mark for upgrade": "Seleziona per aggiornamento", "Installed": "Installata", "Search packages": "Cerca pacchetto", "Upgradeable": "Aggiornabile", "pending": "in attesa", "Cancel": "Annulla", "Close": "Chiudi", "Update package list": "Aggiorna la lista dei pacchetti", "Packages": "Pacchetti", "Mark for removal": "Seleziona per rimozione"}