{"": "", "Install/remove packages": "Asenna/poista paketteja", "Apply changes": "", "Selections": "Valinnat", "Mark for installation": "Merkitse asennettavaksi", "Mark for upgrade": "Merkitse p\u00e4ivitett\u00e4v\u00e4ksi", "Installed": "Asennettu", "Search packages": "Etsi paketteja", "Upgradeable": "P\u00e4ivitett\u00e4viss\u00e4", "pending": "vireill\u00e4", "Cancel": "Peruuta", "Close": "Sulje", "Update package list": "P\u00e4ivit\u00e4 pakettiluettelo", "Packages": "Paketit", "Mark for removal": "Merkitse poistettavaksi"}