{"": "", "Install/remove packages": "Installer/supprimer des paquets", "Apply changes": "Appliquer les modifications", "Selections": "S\u00e9lections", "Mark for installation": "Marquer pour installation", "Mark for upgrade": "Marquer pour mise \u00e0 jour", "Installed": "Install\u00e9", "Search packages": "Chercher un paquet", "Upgradeable": "Nouvelle version disponible", "pending": "en attente", "Cancel": "Annuler", "Close": "Fermer", "Update package list": "Mettre \u00e0 jour la liste des paquets", "Packages": "Paquets", "Mark for removal": "Marquer pour suppression"}